@@ -6,7 +6,7 @@
 // KIND, either express or implied. Please review the Licences for the specific language governing
 // permissions and limitations relating to use of the SAFE Network Software.
 
-use super::{delivery_group, Comm, Core};
+use super::{delivery_group, Comm, Node};
 
 use crate::messaging::{
     system::{JoinResponse, MembershipState, NodeState, SigShare, SystemMsg},
@@ -16,11 +16,9 @@ use crate::node::{
     api::cmds::Cmd,
     error::Result,
     network_knowledge::{NetworkKnowledge, SectionAuthorityProvider, SectionKeyShare},
-    node_info::Node,
-    Event,
+    Event, NodeInfo,
 };
-use crate::peer::Peer;
-use crate::types::log_markers::LogMarker;
+use crate::types::{log_markers::LogMarker, Peer};
 use crate::UsedSpace;
 
 use secured_linked_list::SecuredLinkedList;
@@ -28,11 +26,11 @@ use std::{collections::BTreeSet, net::SocketAddr, path::PathBuf};
 use tokio::sync::mpsc;
 use xor_name::XorName;
 
-impl Core {
+impl Node {
     // Creates `Core` for the first node in the network
     pub(crate) async fn first_node(
         comm: Comm,
-        mut node: Node,
+        mut node: NodeInfo,
         event_tx: mpsc::Sender<Event>,
         used_space: UsedSpace,
         root_storage_dir: PathBuf,
@@ -57,7 +55,7 @@ impl Core {
 
     pub(crate) async fn relocate(
         &self,
-        mut new_node: Node,
+        mut new_node: NodeInfo,
         new_section: NetworkKnowledge,
     ) -> Result<()> {
         // we first try to relocate section info.
@@ -66,7 +64,7 @@ impl Core {
         // make sure the new Node has the correct local addr as Comm
         new_node.addr = self.comm.our_connection_info();
 
-        let mut our_node = self.node.write().await;
+        let mut our_node = self.info.write().await;
         *our_node = new_node;
 
         Ok(())
@@ -83,7 +81,7 @@ impl Core {
     /// Is this node an elder?
     pub(crate) async fn is_elder(&self) -> bool {
         self.network_knowledge
-            .is_elder(&self.node.read().await.name())
+            .is_elder(&self.info.read().await.name())
             .await
     }
 
@@ -138,7 +136,7 @@ impl Core {
 
     pub(crate) async fn handle_timeout(&self, token: u64) -> Result<Vec<Cmd>> {
         self.dkg_voter.handle_timeout(
-            &self.node.read().await.clone(),
+            &self.info.read().await.clone(),
             token,
             self.network_knowledge().section_key().await,
         )
@@ -149,7 +147,7 @@ impl Core {
         let dst_location = wire_msg.dst_location();
         let (targets, dg_size) = delivery_group::delivery_targets(
             dst_location,
-            &self.node.read().await.name(),
+            &self.info.read().await.name(),
             &self.network_knowledge,
         )
         .await?;
@@ -204,7 +202,7 @@ impl Core {
         excluded_names: &BTreeSet<XorName>,
     ) -> Result<Vec<Cmd>> {
         let mut cmds = vec![];
-        let our_name = self.node.read().await.name();
+        let our_name = self.info.read().await.name();
 
         debug!("{}", LogMarker::TriggeringPromotionAndDemotion);
         for elder_candidates in self
